@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::GenPericmdScript;
 
-our $DATE = '2016-12-15'; # DATE
-our $VERSION = '0.34'; # VERSION
+our $DATE = '2017-01-06'; # DATE
+our $VERSION = '0.35'; # VERSION
 
 use 5.010001;
 use strict;
@@ -50,6 +50,8 @@ has default_dry_run => (is=>'rw');
 has allow_prereq => (is=>'rw');
 has per_arg_json => (is=>'rw');
 has per_arg_yaml => (is=>'rw');
+has validate_args => (is=>'rw');
+has pack_deps => (is=>'rw');
 
 sub mvp_multivalue_args { qw(build_load_modules load_modules code_before_instantiate_cmdline code_after_end config_filename config_dirs allow_prereq) }
 
@@ -158,6 +160,8 @@ sub munge_files {
             (allow_prereq => $self->allow_prereq) x !!$self->allow_prereq,
             (per_arg_json => $self->per_arg_json) x !!defined($self->per_arg_json),
             (per_arg_yaml => $self->per_arg_yaml) x !!defined($self->per_arg_yaml),
+            (validate_args => $self->validate_args) x !!defined($self->validate_args),
+            (pack_deps => $self->pack_deps) x !!defined($self->pack_deps),
         );
         #use DD; dd \%gen_args;
         $res = gen_pericmd_script(%gen_args);
@@ -250,7 +254,7 @@ Dist::Zilla::Plugin::GenPericmdScript - Generate Perinci::CmdLine script
 
 =head1 VERSION
 
-This document describes version 0.34 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2016-12-15.
+This document describes version 0.35 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2017-01-06.
 
 =head1 SYNOPSIS
 
@@ -467,7 +471,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
